﻿using System.Collections;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Imaging;
using UnityEngine;

public class AnimatedGifPlayer : MonoBehaviour {

    public string loadingGifPath;
    public float cycleTime; // [s]
    List<Texture2D> gifFrames = new List<Texture2D>();
    int frameIndex;
    float deltaTime;
    float timer;

    // Use this for initialization
    void Start () {
        var gifImage = Image.FromFile(loadingGifPath);
        if (gifImage == null)
        {
            print(message: "file not loaded");
        }
        var dimension = new FrameDimension(gifImage.FrameDimensionsList[0]);
        int frameCount = gifImage.GetFrameCount(dimension);
        for (int i = 0; i < frameCount; i++)
        {
            gifImage.SelectActiveFrame(dimension, i);
            var frame = new Bitmap(gifImage.Width, gifImage.Height);
            System.Drawing.Graphics.FromImage(frame).DrawImage(gifImage, Point.Empty);
            var frameTexture = new Texture2D(frame.Width, frame.Height);
            for (int x = 0; x < frame.Width; x++)
            {
                for (int y = 0; y < frame.Height; y++)
                {
                    System.Drawing.Color sourceColor = frame.GetPixel(x, y);
                    frameTexture.SetPixel(frame.Width - 1 - x, /*frame.Height - 1 - y*/ y, new Color32(sourceColor.R, sourceColor.G, sourceColor.B, sourceColor.A)); // for some reason, x is flipped
                }
            }
            frameTexture.Apply();
            gifFrames.Add(frameTexture);
        }
        if (gifFrames.Count > 0)
        {
            deltaTime = cycleTime / gifFrames.Count;
            timer = 0;
            frameIndex = 0;
            GetComponent<Renderer>().material.mainTexture = gifFrames[0];
        }
    }

    // Update is called once per frame
    void Update () {
        timer += Time.deltaTime;
        if (timer >= deltaTime)
        {
            timer -= deltaTime;
            if (gifFrames.Count > 0)
            {
                frameIndex++;
                if (frameIndex == gifFrames.Count)
                {
                    frameIndex = 0;
                }
                GetComponent<Renderer>().material.mainTexture = gifFrames[frameIndex];
            }
        }
    }

}
